@@ -117,7 +117,7 @@ class RulesCollection(object):
     def extend(self, more):
         self.rules.extend(more)
 
-    def run(self, playbookfile, tags=set(), skip_list=set()):
+    def run(self, playbookfile, tags=set(), skip_list=frozenset()):
         text = ""
         matches = list()
 
@@ -180,12 +180,12 @@ class Match(object):
 class Runner(object):
 
     def __init__(self, rules, playbook, tags, skip_list, exclude_paths,
-                 verbosity=0):
+                 verbosity=0, checked_files=None):
         self.rules = rules
         self.playbooks = set()
         # assume role if directory
         if os.path.isdir(playbook):
-            self.playbooks.add((playbook, 'role'))
+            self.playbooks.add((os.path.join(playbook, ''), 'role'))
             self.playbook_dir = playbook
         else:
             self.playbooks.add((playbook, 'playbook'))
@@ -194,6 +194,9 @@ class Runner(object):
         self.skip_list = skip_list
         self._update_exclude_paths(exclude_paths)
         self.verbosity = verbosity
+        if checked_files is None:
+            checked_files = set()
+        self.checked_files = checked_files
 
     def _update_exclude_paths(self, exclude_paths):
         if exclude_paths:
@@ -231,10 +234,14 @@ class Runner(object):
                 visited.add(arg)
 
         matches = list()
+        # remove files that have already been checked
+        files = [x for x in files if x['path'] not in self.checked_files]
         for file in files:
             if self.verbosity > 0:
                 print("Examining %s of type %s" % (file['path'], file['type']))
             matches.extend(self.rules.run(file, tags=set(self.tags),
-                           skip_list=set(self.skip_list)))
+                           skip_list=self.skip_list))
+        # update list of checked files
+        self.checked_files.update([x['path'] for x in files])
 
         return matches
