@@ -23,11 +23,15 @@ from ansiblelint.utils import LINE_NUMBER_KEY, FILENAME_KEY
 
 
 class EnvVarsInCommandRule(AnsibleLintRule):
-    id = 'ANSIBLE0014'
+    id = '304'
     shortdesc = "Environment variables don't work as part of command"
-    description = 'Environment variables should be passed to shell or ' \
-                  'command through environment argument'
-    tags = ['bug']
+    description = (
+        'Environment variables should be passed to ``shell`` or ``command`` '
+        'through environment argument'
+    )
+    severity = 'VERY_HIGH'
+    tags = ['command-shell', 'bug', 'ANSIBLE0014']
+    version_added = 'historic'
 
     expected_args = ['chdir', 'creates', 'executable', 'removes', 'stdin', 'warn',
                      'cmd', '__ansible_module__', '__ansible_arguments__',
