@@ -24,12 +24,16 @@ import six
 
 
 class OctalPermissionsRule(AnsibleLintRule):
-    id = 'ANSIBLE0009'
+    id = '202'
     shortdesc = 'Octal file permissions must contain leading zero'
-    description = 'Numeric file permissions without leading zero can behave ' + \
-        'in unexpected ways. See ' + \
+    description = (
+        'Numeric file permissions without leading zero can behave '
+        'in unexpected ways. See '
         'http://docs.ansible.com/ansible/file_module.html'
-    tags = ['formatting']
+    )
+    severity = 'VERY_HIGH'
+    tags = ['formatting', 'ANSIBLE0009']
+    version_added = 'historic'
 
     _modules = ['assemble', 'copy', 'file', 'ini_file', 'lineinfile',
                 'replace', 'synchronize', 'template', 'unarchive']
