@@ -23,16 +23,20 @@ import re
 
 
 def unjinja(text):
-    return re.sub("\{\{[^\}]*\}\}", "JINJA_VAR", text)
+    return re.sub(r"{{[^}]*}}", "JINJA_VAR", text)
 
 
 class UseCommandInsteadOfShellRule(AnsibleLintRule):
-    id = 'ANSIBLE0013'
+    id = '305'
     shortdesc = 'Use shell only when shell functionality is required'
-    description = 'Shell should only be used when piping, redirecting ' \
-                  'or chaining commands (and Ansible would be preferred ' \
-                  'for some of those!)'
-    tags = ['safety']
+    description = (
+        'Shell should only be used when piping, redirecting '
+        'or chaining commands (and Ansible would be preferred '
+        'for some of those!)'
+    )
+    severity = 'HIGH'
+    tags = ['command-shell', 'safety', 'ANSIBLE0013']
+    version_added = 'historic'
 
     def matchtask(self, file, task):
         # Use unjinja so that we don't match on jinja filters
