@@ -29,11 +29,15 @@ def _changed_in_when(item):
 
 
 class UseHandlerRatherThanWhenChangedRule(AnsibleLintRule):
-    id = 'ANSIBLE0016'
+    id = '503'
     shortdesc = 'Tasks that run when changed should likely be handlers'
-    description = "If a task has a `when: result.changed` setting, it's effectively " \
-                  "acting as a handler"
-    tags = ['behaviour']
+    description = (
+        'If a task has a ``when: result.changed`` setting, it is effectively '
+        'acting as a handler'
+    )
+    severity = 'MEDIUM'
+    tags = ['task', 'behaviour', 'ANSIBLE0016']
+    version_added = 'historic'
 
     def matchtask(self, file, task):
         if task["__ansible_action_type__"] == 'task':
