@@ -24,14 +24,18 @@ from ansiblelint import AnsibleLintRule
 
 
 class UsingBareVariablesIsDeprecatedRule(AnsibleLintRule):
-    id = 'ANSIBLE0015'
+    id = '104'
     shortdesc = 'Using bare variables is deprecated'
-    description = 'Using bare variables is deprecated. Update your ' + \
-        'playbooks so that the environment value uses the full variable ' + \
-        'syntax ("{{your_variable}}").'
-    tags = ['formatting', 'deprecated']
+    description = (
+        'Using bare variables is deprecated. Update your '
+        'playbooks so that the environment value uses the full variable '
+        'syntax ``{{ your_variable }}``'
+    )
+    severity = 'VERY_HIGH'
+    tags = ['deprecated', 'formatting', 'ANSIBLE0015']
+    version_added = 'historic'
 
-    _jinja = re.compile("\{\{.*\}\}")
+    _jinja = re.compile(r"{{.*}}")
     _glob = re.compile('[][*?]')
 
     def matchtask(self, file, task):
