@@ -75,7 +75,6 @@ except ImportError:
         dl.set_basedir(basedir)
         templar = Templar(dl, variables=templatevars)
         return templar.template(varname, **kwargs)
-
     try:
         from ansible.plugins import module_loader
     except ImportError:
@@ -86,7 +85,7 @@ FILENAME_KEY = '__file__'
 
 VALID_KEYS = [
     'name', 'action', 'when', 'async', 'poll', 'notify',
-    'first_available_file', 'include', 'import_playbook',
+    'first_available_file', 'include', 'include_tasks', 'import_tasks', 'import_playbook',
     'tags', 'register', 'ignore_errors', 'delegate_to',
     'local_action', 'transport', 'remote_user', 'sudo',
     'sudo_user', 'sudo_pass', 'when', 'connection', 'environment', 'args', 'always_run',
@@ -207,6 +206,8 @@ def play_children(basedir, item, parent_type, playbook_dir):
         'roles': _roles_children,
         'dependencies': _roles_children,
         'handlers': _taskshandlers_children,
+        'include_tasks': _include_children,
+        'import_tasks': _include_children,
     }
     (k, v) = item
     play_library = os.path.join(os.path.abspath(basedir), 'library')
@@ -247,7 +248,8 @@ def _taskshandlers_children(basedir, k, v, parent_type):
             results.extend(_roles_children(basedir, k, [th['import_role'].get('name')], parent_type,
                                            main=th['import_role'].get('tasks_from', 'main')))
         elif 'include_role' in th:
-            results.extend(_roles_children(basedir, k, [th['include_role'].get('name')], parent_type,
+            results.extend(_roles_children(basedir, k, [th['include_role'].get('name')],
+                                           parent_type,
                                            main=th['include_role'].get('tasks_from', 'main')))
         elif 'block' in th:
             results.extend(_taskshandlers_children(basedir, k, th['block'], parent_type))
@@ -281,7 +283,7 @@ def _roles_children(basedir, k, v, parent_type, main='main'):
                     results.extend(_look_for_role_files(basedir,
                                                         role.get('role', role.get('name')),
                                                         main=main))
-            else:
+            elif k != 'dependencies':
                 raise SystemExit('role dict {0} does not contain a "role" '
                                  'or "name" key'.format(role))
         else:
@@ -305,7 +307,8 @@ def _rolepath(basedir, role):
         path_dwim(
             basedir, os.path.join('..', '..', '..', 'roles', role)
         ),
-        path_dwim(basedir, os.path.join('..', '..', role))
+        path_dwim(basedir, os.path.join('..', '..', role)),
+        path_dwim(basedir, ''),
     ]
 
     if constants.DEFAULT_ROLES_PATH:
@@ -431,7 +434,7 @@ def normalize_task_v1(task):
                     else:
                         # Tasks that include playbooks (rather than task files)
                         # can get here
-                        # https://github.com/willthames/ansible-lint/issues/138
+                        # https://github.com/ansible/ansible-lint/issues/138
                         raise RuntimeError("Was not expecting value %s of type %s for key %s\n"
                                            "Task: %s. Check the syntax of your playbook using "
                                            "ansible-playbook --syntax-check" %
